@@ -2,4 +2,4 @@ from __future__ import absolute_import
 from .__version__ import __version__
 from . import utKit
 from . import cl_utils
-from . import docstring_test
+from .docstring_test import docstring_test
